@@ -400,7 +400,7 @@ class CoreEmailCommand(DefaultCommand):
 
 
 class CoreWebCommand(DefaultCommand):
-    """Dav command"""
+    """Core Web command"""
 
     MSG_UPDATING = "Updating core/web module."
     MSG_UPDATED = "core/web module updated."
@@ -424,6 +424,118 @@ class CoreWebCommand(DefaultCommand):
         ]
         return self.update(self.default_endpoint, data, legends)
 
+class CoreWebserverCommand(DefaultCommand):
+    """Core Webserver command"""
+
+    MSG_UPDATING = "Updating core/webserver module."
+    MSG_UPDATED = "core/webserver module updated."
+    MSG_ERROR_UPDATE = "Can not update core/webserver module"
+
+    def __call__(self, args):
+        super(CoreWebserverCommand, self).__call__(args)
+        data = [{
+            "name": "core",
+            "configurations": [
+                {
+                    "name": "webserver",
+                    "value": {
+                        "proxy": {
+                            "trust": args.trust
+                        },
+                        "maxAge": args.max_age
+                    }
+                }
+            ]
+        }]
+        legends = [
+            "Updating esn webserver configuration ...",
+        ]
+        return self.update(self.default_endpoint, data, legends)
+
+class CoreSessionCommand(DefaultCommand):
+    """Core session command"""
+
+    MSG_UPDATING = "Updating core/session module."
+    MSG_UPDATED = "core/session module updated."
+    MSG_ERROR_UPDATE = "Can not update core/session module"
+
+    def get_session_configuration(self):
+        data = [{
+            "name": "core",
+            "keys": ["session"]
+        }]
+
+        r = self.session.post(self.base_url + self.default_endpoint,
+            data=json.dumps(data),
+            headers=self.headers,
+            auth=HTTPBasicAuth(self.login, self.password),
+            verify=not self.no_verify)
+
+        if r.status_code != 200:
+            self.log.error("Can't retrieve session configuration.")
+            return
+
+        self.log.debug("data : %s", r.json())
+
+        if ("value" in r.json()[0]['configurations'][0]):
+            return r.json()[0]['configurations'][0]['value']
+
+        return
+
+    def __call__(self, args):
+        super(CoreSessionCommand, self).__call__(args)
+
+        sessionConfiguration = self.get_session_configuration()
+
+        if not sessionConfiguration:
+            sessionConfiguration = {
+                "secret": args.session_secret_key,
+                "cookie": {
+                    "maxAge": args.session_ttl
+                }
+            }
+        else:
+            sessionConfiguration["secret"] = args.session_secret_key
+            sessionConfiguration["cookie"]["maxAge"] = args.session_ttl
+
+        data = [{
+            "name": "core",
+            "configurations": [
+                {
+                    "name": "session",
+                    "value": sessionConfiguration
+                }
+            ]
+        }]
+        legends = [
+            "Updating esn session ...",
+        ]
+        return self.update(self.default_endpoint, data, legends)
+
+class CoreOpenidConnectCommand(DefaultCommand):
+    """Core OpenidConnect command"""
+
+    MSG_UPDATING = "Updating core/openid-connect module."
+    MSG_UPDATED = "core/openid-connect module updated."
+    MSG_ERROR_UPDATE = "Can not update core/openid-connect module"
+
+    def __call__(self, args):
+        super(CoreOpenidConnectCommand, self).__call__(args)
+        value = json.loads(args.json)
+
+        data = [{
+            "name": "core",
+            "configurations": [
+                {
+                    "name": "openid-connect",
+                    "value": value
+                }
+            ]
+        }]
+        legends = [
+            "Updating esn openid-connect configuration ...",
+        ]
+        return self.update(self.default_endpoint, data, legends)
 
 class InboxCommand(DefaultCommand):
     """Dav command"""
@@ -457,10 +569,6 @@ class InboxCommand(DefaultCommand):
                     "name": "isJmapSendingEnabled",
                     "value": True
                 },
-                {
-                    "name": "isSaveDraftBeforeSendingEnabled",
-                    "value": False
-                },
                 {
                     "name": "maxSizeUpload",
                     "value": 20971520
@@ -866,6 +974,34 @@ class CreateDomainCommand(DefaultCommand):
 
         return self.allow_users_to_setup_forwardings(new_domain_id, args.new_admin_email, args.new_admin_password)
 
+class SynchronizeDomainMembersAddressbookCommand(DefaultCommand):
+    """Synchronize Domain Members Addresbook command"""
+
+    def synchronize_domain_member_addressbooks(self, admin_login, admin_password, only_synchronize_my_domain):
+        endpoint = '/contact/api/addressbooks/domainmembers/synchronize'
+
+        if only_synchronize_my_domain:
+            endpoint += '?domain_id=' + self.get_my_domain_id()
+
+        r = self.session.post(self.base_url + endpoint,
+            headers=self.headers,
+            auth=HTTPBasicAuth(admin_login, admin_password),
+            verify=not self.no_verify)
+
+        if r.status_code == 201:
+            self.log.debug("status_code : %s", r.status_code)
+            return r.json()
+
+        self.log.error("Error while synchronizing domain members address book: %s : %s", r.status_code, r.text)
+        return {}
+
+    def __call__(self, args):
+        super(SynchronizeDomainMembersAddressbookCommand, self).__call__(args)
+        jobs = self.synchronize_domain_member_addressbooks(self.login, self.password, args.domain)
+
+        if len(jobs) > 0:
+            for job in jobs:
+                self.log.info("Domain %s: submitted job id %s", job['domainId'], job['jobId'])
 
 class EsnCLI(BasicProgram):
     """Main program."""
@@ -1007,6 +1143,38 @@ class EsnCLI(BasicProgram):
             help="ESN frontend url. ex: https://openpaas.openpaas.org")
         parser.set_defaults(__func__=CoreWebCommand(self.config))
 
+        parser = subparsers.add_parser(
+            'core-webserver',
+            help="Description of core-webserver")
+        parser.add_argument(
+            "-t", "--trust", required=True, default=False,
+            help="Tell ESN that it is sitting behind a proxy and that the X-Forwarded-* header fields may be trusted")
+        parser.add_argument(
+            "-m", "--max-age", default="0",
+            help="Provide a max-age in milliseconds for http caching, defaults to 0. Any value accepted by the ms module is valid cf https://www.npmjs.com/package/ms#readme")
+        parser.set_defaults(__func__=CoreWebserverCommand(self.config))
+
+        # core-session
+        parser = subparsers.add_parser(
+            'core-session',
+            help="Description of core-session")
+        parser.add_argument(
+            "--session-secret-key", required=True,
+            help="The secret used to sign the session ID cookie, change this will log all users out")
+        parser.add_argument(
+            "--session-ttl", required=True, type=int,
+            help="The number of milliseconds until the session ID cookie becomes invalid. Unit is miliseconds")
+        parser.set_defaults(__func__=CoreSessionCommand(self.config))
+
+        # core-openid-connect
+        parser = subparsers.add_parser(
+            'core-openid-connect',
+            help="Description of core-openid-connect")
+        parser.add_argument(
+            "--json", required=True,
+            help="Json configuration string for openid-connect")
+        parser.set_defaults(__func__=CoreOpenidConnectCommand(self.config))
+
         # inbox
         parser = subparsers.add_parser(
             'inbox',
@@ -1149,6 +1317,16 @@ class EsnCLI(BasicProgram):
             help="Branch of the LDAP to look for users of this domain. e.g. ou=mydomain.com,ou=users,dc=openpaas,dc=org")
         parser.set_defaults(__func__=CreateDomainCommand(self.config))
 
+        # synchronize domain members address books for a single domain or entire platform
+        parser = subparsers.add_parser(
+            'synchronize-domain-members-addressbook',
+            help="Synchronize the domain members address book")
+        parser.add_argument(
+            "--domain", default=False,
+            action="store_true",
+            help="""Synchronize only the domain members addressbooks of current user (Default: %(default)s)""")
+        parser.set_defaults(__func__=SynchronizeDomainMembersAddressbookCommand(self.config))
+
 PROG = EsnCLI(
     "esncli",
     desc="Description of program init.esn.config.py.")
